/* MPQSettings.java: Preferences handling for the MPQ app.
 *            Copyright (C) 2012 donfede@casagrau.org
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * created 2012-10-18 donfede@casagrau.org
 * credit to: Android SDK 10 / SipDemo app
 *
 * $Id: MPQSettings.java,v 1.5 2013-04-08 03:19:59 donfede Exp $
 */

package org.casagrau.mpq.mpq_android;

import java.io.File;

import org.casagrau.mpq.mpq_android.SessionsDBProvider.SessionsDB;

import android.content.SharedPreferences;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.preference.EditTextPreference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceManager;
import android.util.Log;

/**
 * Handles MPQ general settings for the app. Pretty much only reads and process
 * the XML description of preferences.
 */
public class MPQSettings extends PreferenceActivity {
	private static final String LOGTAG = "MPQSettings";

	@SuppressWarnings("deprecation")
	@Override
	public void onCreate(Bundle savedInstanceState) {
		// Note that none of the preferences are actually defined here.
		// They're all in the XML file res/xml/preferences.xml.
		super.onCreate(savedInstanceState);
		addPreferencesFromResource(R.xml.preferences);
	}
	
	/**
	 * Customize preference display of SD card space.
	 */
	@SuppressWarnings("deprecation")
	@Override
	public void onResume() {
		super.onResume();
		
		EditTextPreference letp = (EditTextPreference) findPreference(getString(R.string.pref_audiomax_key)) ;
		long lspace_total_mb = 0;
		long lspace_free_mb = 0;
		SharedPreferences lsharedPref = PreferenceManager.getDefaultSharedPreferences(this);
		String laudioDirPref = lsharedPref.getString(getString(R.string.pref_audiodirectory_key), getString(R.string.pref_audiodirectory_default));
		File lFile = new File(Environment.getExternalStorageDirectory().getAbsolutePath() + laudioDirPref);
		lspace_total_mb = lFile.getTotalSpace() / 1024 / 1024;
		lspace_free_mb = lFile.getUsableSpace() / 1024 / 1024;
		
		// Query total audio file usage.
        Uri luri = SessionsDB.CONTENT_PRACTICES_FILE_SUM_KB;
        Log.d(LOGTAG, "onResume() 07   uri: " + luri);
        long lfile_sum_kb = 0;
        
        Cursor lcursor = getContentResolver().query(luri, null, null, null, null);
		if ( (null != lcursor) && (1 == lcursor.getCount()) ) {
			Log.d(LOGTAG, "onResume() 12 cursor: " + lcursor.toString() );
			lfile_sum_kb = lcursor.getLong(0);
			Log.d(LOGTAG, "onResume() 13  file sum kb: " + lfile_sum_kb);
		}		
		long lfile_sum_mb = lfile_sum_kb / 1024;
		Log.d(LOGTAG, "onResume() 06  tot:" + lspace_total_mb + " usable: " + lspace_free_mb);

		letp.setSummary(getString(R.string.pref_audiomax_summary) + " " + lspace_total_mb + "/" + lspace_free_mb + "\nUsed by MPQ: " + lfile_sum_mb);
	}
}
